##  Prerequisites
  * In SAP LeanIX:
    * Get admin access to your workspace.
    * Ensure that the workspace is provisioned for self-built software discovery. For details, see [Workspace Setup for Self-Built Software Discovery](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD "Provision the self-built software discovery feature in SAP LeanIX to enable microservice discovery. This extends the meta model with microservice fact sheets, custom relations, and additional context fields.").
    * Create a technical user with admin permissions. Learn how in [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").
  * Get admin permissions for your organization on GitHub. This is necessary to install and manage the GitHub App.
  * Coordinate with the relevant stakeholders in your organization to deploy the on-premise GitHub agent on your infrastructure. They will also need to provide the URL where the agent is accessible within your network for the GitHub App creation.
